#version 130

in vec3 inPosition;
in vec2 inTexcoord;
in vec3 inNormal;

out vec3 worldPosition;
out vec2 texcoord;
out vec3 normal;

//// SHADOW MAPPING ////
out vec4 ShadowCoord;


// --------------------------
// GEOMETRY EFFECT PARAMETERS

uniform mat4 WorldMatrix;
uniform mat4 ViewProjectionMatrix;

//// SHADOW MAPPING ////
uniform mat4 DepthBiasMVP;


// --------------------------
// BASIC EFFECT PARAMETERS

// Scaling factor for the texture coordinates.
uniform float TexcoordScale;


void main()
{
	// Calculate the world space and clip space positions.
	worldPosition = (WorldMatrix * vec4(inPosition, 1)).xyz;
	gl_Position = ViewProjectionMatrix * vec4(worldPosition, 1);

	//// SHADOW MAPPING ////
	ShadowCoord = DepthBiasMVP * vec4(worldPosition,1);

	// Transform the texture coordinates.
	texcoord = vec2(1 - inTexcoord.x, inTexcoord.y) * TexcoordScale;

	// Bring the normal to world space.
	normal = (WorldMatrix * vec4(inNormal, 0)).xyz;
	normal = normalize(normal);
}