#version 130

in vec2 texcoords;
out vec4 fragColor;

uniform sampler2D image;
uniform sampler2D bloom;

vec3 adjustSaturation(vec3 color, float saturation)
{
    float grey = dot(color, vec3(0.3, 0.59, 0.11));
    return grey + saturation * (color - grey);
}
 
void main()
{
	float bloomIntensity = 1.2;
	float originalIntensity = 0.94;
	float bloomSaturation = 1.0;
	float originalSaturation = 0.92;

	// Get the bloom pixel from the blurred bright pass.
	vec3 bloomColor = texture(bloom, texcoords).rgb;
 
	// Get the original pixel from the image.
	vec3 originalColor = texture(image, texcoords).rgb;
   
	// Adjust color saturation.
	bloomColor = adjustSaturation(bloomColor, bloomSaturation) * bloomIntensity;
	originalColor = adjustSaturation(originalColor, originalSaturation) * originalIntensity;
   
	// Make the originalColor darker in very bright areas, avoiding these areas look burned-out.
	originalColor *= (1 - clamp(bloomColor, 0.0, 1.0));
   
	// Combine the two images.
	fragColor = vec4(originalColor + bloomColor, 1.0);
}